@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 from sqlbuilder import smartsql as sb
 from pyar import exc, url, util
@@ -59,7 +59,7 @@ class Model(ModelBase):
     		_using = 'default'
 
         self.logger = util.getLogger('.'.join((__name__, _using)))
-    	_dns = pyar.settings.DATABASES.get(_using, None)
+    	_dns = pyar.settings.DNS.get(_using, None)
         if not _dns:
         	raise exc.DnsStringNotFoundError(
         		"Not Found DNS String '%s' for settings" % _using)
